@@ -16,10 +16,18 @@ pub struct Opt {
     #[structopt(short, long)]
     pub stack: bool,
 
+    /// Split VEP's CSQ string into fields
+    #[structopt(short, long)]
+    pub vep_fields: bool,
+
     /// comma separated output (default is tab)
     #[structopt(short, long)]
     pub csv: bool,
 
+    ///input is BGZF compressed (unnecessary if `-i` has suffix `.gz`)
+    #[structopt(short, long)]
+    pub bgzip: bool,
+
     /// Delimiting character to join sample names to fmt fields (default is "_")
     #[structopt(short = "j", long = "sample-delim")]
     pub sample_delim: Option<String>,
